# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic
from .return_prompt import ReturnPrompt
from .return_voice import ReturnVoice
from .return_language_model import ReturnLanguageModel
from .return_ellm_model import ReturnEllmModel
from .return_user_defined_tool import ReturnUserDefinedTool
from .return_builtin_tool import ReturnBuiltinTool
from .return_event_message_specs import ReturnEventMessageSpecs
from .return_timeout_specs import ReturnTimeoutSpecs
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class ReturnConfig(UniversalBaseModel):
    """
    A specific config version returned from the server
    """

    id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Identifier for a Config. Formatted as a UUID.
    """

    version: typing.Optional[int] = pydantic.Field(default=None)
    """
    Version number for a Config.
    
    Configs, Prompts, Custom Voices, and Tools are versioned. This versioning system supports iterative development, allowing you to progressively refine configurations and revert to previous versions if needed.
    
    Version numbers are integer values representing different iterations of the Config. Each update to the Config increments its version number.
    """

    evi_version: typing.Optional[str] = pydantic.Field(default=None)
    """
    Specifies the EVI version to use. Use `"1"` for version 1, or `"2"` for the latest enhanced version. For a detailed comparison of the two versions, refer to our [guide](/docs/empathic-voice-interface-evi/evi-2).
    """

    version_description: typing.Optional[str] = pydantic.Field(default=None)
    """
    An optional description of the Config version.
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Name applied to all versions of a particular Config.
    """

    created_on: typing.Optional[int] = pydantic.Field(default=None)
    """
    Time at which the Config was created. Measured in seconds since the Unix epoch.
    """

    modified_on: typing.Optional[int] = pydantic.Field(default=None)
    """
    Time at which the Config was last modified. Measured in seconds since the Unix epoch.
    """

    prompt: typing.Optional[ReturnPrompt] = None
    voice: typing.Optional[ReturnVoice] = pydantic.Field(default=None)
    """
    A voice specification associated with this Config.
    """

    language_model: typing.Optional[ReturnLanguageModel] = pydantic.Field(default=None)
    """
    The supplemental language model associated with this Config.
    
    This model is used to generate longer, more detailed responses from EVI. Choosing an appropriate supplemental language model for your use case is crucial for generating fast, high-quality responses from EVI.
    """

    ellm_model: typing.Optional[ReturnEllmModel] = pydantic.Field(default=None)
    """
    The eLLM setup associated with this Config.
    
    Hume's eLLM (empathic Large Language Model) is a multimodal language model that takes into account both expression measures and language. The eLLM generates short, empathic language responses and guides text-to-speech (TTS) prosody.
    """

    tools: typing.Optional[typing.List[typing.Optional[ReturnUserDefinedTool]]] = pydantic.Field(default=None)
    """
    List of user-defined tools associated with this Config.
    """

    builtin_tools: typing.Optional[typing.List[typing.Optional[ReturnBuiltinTool]]] = pydantic.Field(default=None)
    """
    List of built-in tools associated with this Config.
    """

    event_messages: typing.Optional[ReturnEventMessageSpecs] = None
    timeouts: typing.Optional[ReturnTimeoutSpecs] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
